<?php

namespace Moblyze\Logbook\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Moblyze\Logbook\Http\Requests\EmergencyDrillRequest;
use Moblyze\Logbook\Interfaces\EmergencyDrillRepositoryInterface;
use Moblyze\Logbook\Models\EmergencyDrill;

/**
 * Resource controller class for emergency_drill.
 */
class EmergencyDrillResourceController extends BaseController
{

    /**
     * Initialize emergency_drill resource controller.
     *
     * @param type EmergencyDrillRepositoryInterface $emergency_drill
     *
     * @return null
     */
    public function __construct(EmergencyDrillRepositoryInterface $emergency_drill)
    {
        parent::__construct();
        $this->repository = $emergency_drill;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Moblyze\Logbook\Repositories\Criteria\EmergencyDrillResourceCriteria::class);
    }

    /**
     * Display a list of emergency_drill.
     *
     * @return Response
     */
    public function index(EmergencyDrillRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Moblyze\Logbook\Repositories\Presenter\EmergencyDrillPresenter::class)
                ->$function();
        }

        $emergency_drills = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('logbook::emergency_drill.names'))
            ->view('logbook::emergency_drill.index', true)
            ->data(compact('emergency_drills', 'view'))
            ->output();
    }

    /**
     * Display emergency_drill.
     *
     * @param Request $request
     * @param Model   $emergency_drill
     *
     * @return Response
     */
    public function show(EmergencyDrillRequest $request, EmergencyDrill $emergency_drill)
    {

        if ($emergency_drill->exists) {
            $view = 'logbook::emergency_drill.show';
        } else {
            $view = 'logbook::emergency_drill.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('logbook::emergency_drill.name'))
            ->data(compact('emergency_drill'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new emergency_drill.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(EmergencyDrillRequest $request)
    {

        $emergency_drill = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('logbook::emergency_drill.name')) 
            ->view('logbook::emergency_drill.create', true) 
            ->data(compact('emergency_drill'))
            ->output();
    }

    /**
     * Create new emergency_drill.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(EmergencyDrillRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $emergency_drill                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('logbook::emergency_drill.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('logbook/emergency_drill/' . $emergency_drill->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/logbook/emergency_drill'))
                ->redirect();
        }

    }

    /**
     * Show emergency_drill for editing.
     *
     * @param Request $request
     * @param Model   $emergency_drill
     *
     * @return Response
     */
    public function edit(EmergencyDrillRequest $request, EmergencyDrill $emergency_drill)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('logbook::emergency_drill.name'))
            ->view('logbook::emergency_drill.edit', true)
            ->data(compact('emergency_drill'))
            ->output();
    }

    /**
     * Update the emergency_drill.
     *
     * @param Request $request
     * @param Model   $emergency_drill
     *
     * @return Response
     */
    public function update(EmergencyDrillRequest $request, EmergencyDrill $emergency_drill)
    {
        try {
            $attributes = $request->all();

            $emergency_drill->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('logbook::emergency_drill.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('logbook/emergency_drill/' . $emergency_drill->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('logbook/emergency_drill/' . $emergency_drill->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the emergency_drill.
     *
     * @param Model   $emergency_drill
     *
     * @return Response
     */
    public function destroy(EmergencyDrillRequest $request, EmergencyDrill $emergency_drill)
    {
        try {

            $emergency_drill->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('logbook::emergency_drill.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('logbook/emergency_drill/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('logbook/emergency_drill/' . $emergency_drill->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple emergency_drill.
     *
     * @param Model   $emergency_drill
     *
     * @return Response
     */
    public function delete(EmergencyDrillRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('logbook::emergency_drill.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('logbook/emergency_drill'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/logbook/emergency_drill'))
                ->redirect();
        }

    }

    /**
     * Restore deleted emergency_drills.
     *
     * @param Model   $emergency_drill
     *
     * @return Response
     */
    public function restore(EmergencyDrillRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('logbook::emergency_drill.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/logbook/emergency_drill'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/logbook/emergency_drill/'))
                ->redirect();
        }

    }

}
