<?php

namespace Moblyze\Logbook\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Moblyze\Logbook\Http\Requests\PassengerManifestRequest;
use Moblyze\Logbook\Interfaces\PassengerManifestRepositoryInterface;
use Moblyze\Logbook\Models\PassengerManifest;

/**
 * Resource controller class for passenger_manifest.
 */
class PassengerManifestResourceController extends BaseController
{

    /**
     * Initialize passenger_manifest resource controller.
     *
     * @param type PassengerManifestRepositoryInterface $passenger_manifest
     *
     * @return null
     */
    public function __construct(PassengerManifestRepositoryInterface $passenger_manifest)
    {
        parent::__construct();
        $this->repository = $passenger_manifest;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Moblyze\Logbook\Repositories\Criteria\PassengerManifestResourceCriteria::class);
    }

    /**
     * Display a list of passenger_manifest.
     *
     * @return Response
     */
    public function index(PassengerManifestRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Moblyze\Logbook\Repositories\Presenter\PassengerManifestPresenter::class)
                ->$function();
        }

        $passenger_manifests = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('logbook::passenger_manifest.names'))
            ->view('logbook::passenger_manifest.index', true)
            ->data(compact('passenger_manifests', 'view'))
            ->output();
    }

    /**
     * Display passenger_manifest.
     *
     * @param Request $request
     * @param Model   $passenger_manifest
     *
     * @return Response
     */
    public function show(PassengerManifestRequest $request, PassengerManifest $passenger_manifest)
    {

        if ($passenger_manifest->exists) {
            $view = 'logbook::passenger_manifest.show';
        } else {
            $view = 'logbook::passenger_manifest.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('logbook::passenger_manifest.name'))
            ->data(compact('passenger_manifest'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new passenger_manifest.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PassengerManifestRequest $request)
    {

        $passenger_manifest = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('logbook::passenger_manifest.name')) 
            ->view('logbook::passenger_manifest.create', true) 
            ->data(compact('passenger_manifest'))
            ->output();
    }

    /**
     * Create new passenger_manifest.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PassengerManifestRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $passenger_manifest                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('logbook::passenger_manifest.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('logbook/passenger_manifest/' . $passenger_manifest->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/logbook/passenger_manifest'))
                ->redirect();
        }

    }

    /**
     * Show passenger_manifest for editing.
     *
     * @param Request $request
     * @param Model   $passenger_manifest
     *
     * @return Response
     */
    public function edit(PassengerManifestRequest $request, PassengerManifest $passenger_manifest)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('logbook::passenger_manifest.name'))
            ->view('logbook::passenger_manifest.edit', true)
            ->data(compact('passenger_manifest'))
            ->output();
    }

    /**
     * Update the passenger_manifest.
     *
     * @param Request $request
     * @param Model   $passenger_manifest
     *
     * @return Response
     */
    public function update(PassengerManifestRequest $request, PassengerManifest $passenger_manifest)
    {
        try {
            $attributes = $request->all();

            $passenger_manifest->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('logbook::passenger_manifest.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('logbook/passenger_manifest/' . $passenger_manifest->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('logbook/passenger_manifest/' . $passenger_manifest->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the passenger_manifest.
     *
     * @param Model   $passenger_manifest
     *
     * @return Response
     */
    public function destroy(PassengerManifestRequest $request, PassengerManifest $passenger_manifest)
    {
        try {

            $passenger_manifest->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('logbook::passenger_manifest.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('logbook/passenger_manifest/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('logbook/passenger_manifest/' . $passenger_manifest->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple passenger_manifest.
     *
     * @param Model   $passenger_manifest
     *
     * @return Response
     */
    public function delete(PassengerManifestRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('logbook::passenger_manifest.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('logbook/passenger_manifest'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/logbook/passenger_manifest'))
                ->redirect();
        }

    }

    /**
     * Restore deleted passenger_manifests.
     *
     * @param Model   $passenger_manifest
     *
     * @return Response
     */
    public function restore(PassengerManifestRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('logbook::passenger_manifest.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/logbook/passenger_manifest'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/logbook/passenger_manifest/'))
                ->redirect();
        }

    }

}
